Licensing translations
======================
You can specify which license translations are contributed under.
This is especially important to do if translations are
open to the public, to stipulate what they can be used for.

You should specify :ref:`component` license info.
You should avoid requiring a contributor license agreement, though it is possible.

License info
------------

Upon specifying license info (license name and URL), this info is
shown in the translation info section of the respective :ref:`component`.

Usually this is best place to post licensing info if no explicit consent is required.
If your project or translation is not libre you most probably need prior consent.

Contributor agreement
---------------------

If you specify a contributor license agreement, only users who have agreed to it will
be able to contribute. This is a clearly visible step when accessing the translation:

.. image:: /images/contributor-agreement.png

The entered text is formatted into paragraphs and external links can be included.
HTML markup can not be used.

User licenses
-------------

Any user can review all translation licenses of all public projects on the instance from their profile:

.. image:: /images/profile-licenses.png
